@@ -24,7 +24,7 @@ RSpec::Support.require_rspec_support "directory_maker"
 # ## Custom Formatters
 #
 # You can tell RSpec to use a custom formatter by passing its path and name to
-# the `rspec` commmand. For example, if you define MyCustomFormatter in
+# the `rspec` command. For example, if you define MyCustomFormatter in
 # path/to/my_custom_formatter.rb, you would type this command:
 #
 #     rspec --require path/to/my_custom_formatter.rb --format MyCustomFormatter
@@ -115,6 +115,11 @@ module RSpec::Core::Formatters
     # @return [String] the default formatter to setup, defaults to `progress`
     attr_accessor :default_formatter
 
+    # @private
+    def prepare_default(output_stream, deprecation_stream)
+      reporter.prepare_default(self, output_stream, deprecation_stream)
+    end
+
     # @private
     def setup_default(output_stream, deprecation_stream)
       add default_formatter, output_stream if @formatters.empty?
@@ -140,7 +145,7 @@ module RSpec::Core::Formatters
     def add(formatter_to_use, *paths)
       formatter_class = find_formatter(formatter_to_use)
 
-      args = paths.map { |p| p.respond_to?(:puts) ? p : file_at(p) }
+      args = paths.map { |p| p.respond_to?(:puts) ? p : open_stream(p) }
 
       if !Loader.formatters[formatter_class].nil?
         formatter = formatter_class.new(*args)
@@ -247,9 +252,14 @@ module RSpec::Core::Formatters
       word
     end
 
-    def file_at(path)
-      RSpec::Support::DirectoryMaker.mkdir_p(File.dirname(path))
-      File.new(path, 'w')
+    def open_stream(path_or_wrapper)
+      if RSpec::Core::OutputWrapper === path_or_wrapper
+        path_or_wrapper.output = open_stream(path_or_wrapper.output)
+        path_or_wrapper
+      else
+        RSpec::Support::DirectoryMaker.mkdir_p(File.dirname(path_or_wrapper))
+        File.new(path_or_wrapper, 'w')
+      end
     end
   end
 end
